//
//  SystemEnhancer.h
//  SystemEnhancer 1.0.3
//
//  Created by Fabian Schuiki on 30.04.05.
//  Copyright 2005 Luxor Development. All rights reserved.
//  http://www.luxordevelopment.ch
//

#import <Foundation/NSBundle.h>
#import <AppKit/NSNibLoading.h>
#import <AppKit/NSApplication.h>
#import <Foundation/NSString.h>
#import <Foundation/NSDictionary.h>

@class NSBundle, NSString, NSDictionary, NSApplication;

/* System versions returned by LSECurrentSystemVersion() */
typedef enum {
	LSESystemVersionUnknown = -1,
	LSESystemVersionCheetah	= 0,
	LSESystemVersionPuma	= 1,
	LSESystemVersionJaguar	= 2,
	LSESystemVersionPanther	= 3,
	LSESystemVersionTiger	= 4
} LSESystemVersion;

/* The system version codenames */
#define	LSESystemVersionStringCheetah	@"Cheetah"
#define	LSESystemVersionStringPuma		@"Puma"
#define	LSESystemVersionStringJaguar	@"Jaguar"
#define	LSESystemVersionStringPanther	@"Panther"
#define	LSESystemVersionStringTiger		@"Tiger"


@interface NSBundle (SystemEnhancerExtensions)

+ (void)setEnhancedNibNameFormat:(NSString *)format;
+ (NSString *)enhancedNibNameFormat;
/* The default value of enhancedNibNameFormat is "%@ (%@)", that would result in e.g.: "Document (Tiger).nib"
 * This is a global value
 * Setting the engancedNibNameFormat to nil will restore the default value
 */

+ (NSString *)bestNibNamed:(NSString *)nibName forSystemVersion:(LSESystemVersion)version inBundle:(NSBundle *)bundle;
/* Returns the most compatible nib file named 'nibName' for the system version 'version' in 'bundle'.
 * If 'bundle' is nil, [NSBundle mainBundle] is used instead
 * Example:
 * English.lproj contents: Document (Jaguar).nib, Document (Tiger).nib
 * -> Calling this function with 'nibName' = "Document.nib" and 'version' = LSESystemVersionPanther would return "Document (Jaguar).nib"
 *
 * If no specific Nib file is found, 'nibName' is returned
 */

+ (BOOL)loadEnhancedNibFile:(NSString *)fileName externalNameTable:(NSDictionary *)context withZone:(NSZone *)zone;
+ (BOOL)loadEnhancedNibNamed:(NSString *)nibName owner:(id)owner;
- (BOOL)loadEnhancedNibFile:(NSString *)fileName externalNameTable:(NSDictionary *)context withZone:(NSZone *)zone;
/* These methods call their according NSBundle method passing the result of bestNibNamed:forSystemVersion:inBundle: for
 * their first value as fileName/nibName.
 */

@end

LSESystemVersion LSECurrentSystemVersion();
/* The current system version */

NSString * LSEStringFromSystemVersion(LSESystemVersion version);
/* Convert the LSESystemVersion 'version' to the string used as name extension for enhanced Nib files */

NSString * LSECurrentSystemVersionString();
/* Calls LSEStringFromSystemVersion() passing the result of LSECurrentSystemVersion() */

BOOL LSECheckCompatibility(LSESystemVersion version);
/* Returns whether methods from system version 'version' are compatible with the current system version
 * Passing LSESystemVersionJaguar on a Panther system would return YES
 * Passing LSESystemVersionTiger on a Panther system would return NO
 */

